@@ -10,7 +10,7 @@ use vars qw(@EXPORT @EXPORT_OK);
     num2asc_desc
 );
 use vars qw($VERSION);
-$VERSION = '0.07.1';
+$VERSION = '0.07';
 
 # sub toggle_resort {{{
 # Transform an order by clause.
@@ -18,8 +18,11 @@ sub toggle_resort {
     my %args = @_;
     _set_defaults(\%args);
 
+    # Declare an ordered array and a direction hash of columns.
+    my ($columns, $direction);
+
     # Set the column name list and the directions.
-    my ($columns, $direction) = get_columns(
+    ($columns, $direction) = get_columns(
         order_by => $args{order_by},
         show_ascending => $args{show_ascending},
         name_direction => 1,
@@ -45,11 +48,9 @@ sub toggle_resort {
         unshift @$columns, $selected;
     }
 
-    # Convert from numeric, if asked to.
     %$direction = num2asc_desc ($direction, $args{show_ascending})
         unless $args{numeric_direction};
-
-    # Fetch our "name direction" array.
+    
     @$columns = col_dir_list ($columns, $direction);
 
     # Return the column ordering as an arrayref or string.
@@ -82,7 +83,7 @@ sub get_columns {
     for (@order) {
         if (/^(.*?)(?:\s+(asc|desc))?$/i) {
             # Use the direction provided; Ascend by default.
-            $direction->{$1} = $2 && lc ($2) eq 'desc' ? 0 : 1;
+            $direction->{$1} = $2 && $2 eq 'desc' ? 0 : 1;
         }
 
         # Add the column to our columns array.
@@ -119,10 +120,10 @@ sub col_dir_list {
 # sub num2asc_desc {{{
 # Return directions as "asc" and "desc" in place of their numeric eqivalents.
 sub num2asc_desc {
-    my ($dir, $show_asc) = @_;
+    my ($dir, $show_ascending) = @_;
     return map {
         $_ => $dir->{$_}
-            ? $show_asc ? 'asc' : ''
+            ? $show_ascending ? 'asc' : ''
             : 'desc'
     } keys %$dir;
 }
@@ -132,7 +133,7 @@ sub num2asc_desc {
 # Naive little default argument setter.
 sub _set_defaults {
     my $args = shift;
-    $args->{show_ascending}    = 0 unless defined $args->{show_ascending};
+    $args->{show_ascending}    = 1 unless defined $args->{show_ascending};
     $args->{name_direction}    = 0 unless defined $args->{name_direction};
     $args->{numeric_direction} = 0 unless defined $args->{numeric_direction};
 }
@@ -151,43 +152,39 @@ SQL::OrderBy - Transform an SQL ORDER BY clause.
 
   # Fetch the columns in array context.
   @columns = get_columns (
-      order_by => 'Name, Artist DESC, Album',
+      order_by => 'name, artist desc, album',
   );
-  # ('Name', 'Artist desc', 'Album')
+  # ('name asc', 'artist desc', 'album asc')
 
-  # Fetch the columns in scalar context.
+  # Fetch the columns in scalar context without the asc keyword.
   $columns = get_columns (
       order_by => ['name', 'artist desc', 'album'],
-      show_ascending => 1,
+      show_ascending => 0,
   );
-  # 'name asc, artist desc, album asc'
+  # 'name, artist desc, album'
 
   # Fetch the columns as a name array and numeric direction hash.
   @columns = get_columns (
       order_by => 'name, artist desc, album',
-      name_direction    => 1,
+      name_direction => 1,
       numeric_direction => 1,
   );
   # (['name','artist','album'], {name=>1, artist=>0, album=>1})
 
-  # Output a "column direction" array.
-  @columns = col_dir_list (\@column_names, \%direction);
-  # ('name', 'artist desc', 'album')
+  @columns = col_dir_list (\@column_names, \%directions);
 
-  # Fetch the directions as SQL keywords.
-  %direction = num2asc_desc (\%direction, 0);
-  # (name=>'asc', artist=>'desc', album=>'asc')
+  %directions = num2asc_desc (\%directions, 0);
 
-  # Single toggle resort in array context.
+  # Toggle resort in array context.
   @order = toggle_resort (
-      show_ascending => 1,
       selected => 'artist',
       order_by => ['name', 'artist', 'album'],
   );
   # ('artist asc', 'name asc', 'album asc')
 
-  # Nested toggle resort in scalar context.
+  # Toggle resort in scalar context without the asc keyword.
   print scalar toggle_resort (
+      show_ascending => 0,
       selected => 'time',
       order_by => scalar toggle_resort(
           selected => 'artist',
@@ -214,7 +211,7 @@ integrity checking is done.
 
 =head1 FUNCTIONS
 
-=head2 toggle_resort
+=head2 toggle_resort ()
 
   toggle_resort(
       order_by => $order_clause_or_list,
@@ -254,11 +251,13 @@ user interacts with a table by sorting and resorting with a mouse and
 "toggle button column headings" during an interactive search
 refinement session.
 
-* If you do not include the selected argument, this function will
-simply return the clause with sort directions for each column name.
-That is, no "toggling" or moving is done.
+* If you leave off the selected argument, this function will simply
+return the clause with sort directions for each column name.  That
+is, no "toggling" or moving is done.
 
-=head2 get_columns
+* Currently, this function is not exported by default.
+
+=head2 get_columns ()
 
   @columns = get_columns (
       order_by => $order_clause_or_list,
@@ -292,9 +291,9 @@ numeric_direction => Return Boolean column directions, instead of
 asc/desc.  Defaults off (0).  Only makes sense with the
 name_direction flag on.
 
-=head2 col_dir_list
+=head2 col_dir_list ()
 
-  @columns = col_dir_list (\@columns, \%direction);
+  @columns = col_dir_list (\@columns, \%asc_desc);
 
 Return an array of column names with their respective directions
 concatinated.
@@ -302,11 +301,11 @@ concatinated.
 This function takes a reference to an array of column names and a
 reference to a direction hash.
 
-=head2 num2asc_desc
+=head2 num2asc_desc ()
 
-  %direction = num2asc_desc (\%direction, $show_asc)
+  %directions = num2asc_desc (\%directions, $show_asc)
 
-Return direction as "asc" and "desc" in place of their numeric
+Return directions as "asc" and "desc" in place of their numeric
 eqivalents.
 
 This function takes a reference to a direction hash and an optional
